@@ -18,8 +18,8 @@ email                : markey@web.de
 
 #include "akregatorpart_export.h"
 
-#include <kservice.h>
-#include <kservicetypetrader.h>
+#include <KService>
+#include <KServiceTypeTrader>
 
 #include <vector>
 
